Enum style_traits::ValueParseErrorKind
[−]
[src]
pub enum ValueParseErrorKind<'i> {
InvalidColor(Token<'i>),
InvalidFilter(Token<'i>),
}Specific errors that can be encountered while parsing property values.
Variants
InvalidColor(Token<'i>)An invalid token was encountered while parsing a color value.
InvalidFilter(Token<'i>)An invalid filter value was encountered.